@@ -1,6 +1,3 @@
-#!/usr/bin/env python
-
-from docopt import docopt
 import sys
 import os
 import re
@@ -25,7 +22,6 @@ from Bio import SeqIO
 import itertools
 import gzip
 from mimetypes import guess_type
-from aMGSIM import __version__
 
 debug = False
 
@@ -58,18 +54,22 @@ def _rename_name(x, output_dir):
     if not os.path.isdir(out_dir):
         os.makedirs(out_dir, exist_ok=True)
 
-    # regexes
-    re0 = re.compile(r".+ complete genome. ")
-    re1 = re.compile(r"\W")
-    re2 = re.compile(r"^_*(.*?)_*$")
-    re3 = re.compile(r"_*complete_genome")
-    re4 = re.compile(r"(.{78}).+")
+    pattern = re.compile(r"(\S+)----(\S+)")
+
     ambig_chars = re.compile(r"[RYSWKMBVDH]")
-    taxon = re0.sub("", taxon)
-    taxon = re1.sub("_", taxon)
-    taxon = re2.sub(r"\1", taxon)
-    taxon = re3.sub("", taxon)
-    taxon = re4.sub(r"\1", taxon)
+    m0 = re.search(pattern, taxon)
+    if m0 is None:
+        # regexes
+        re0 = re.compile(r".+ complete genome. ")
+        re1 = re.compile(r"\W")
+        re2 = re.compile(r"^_*(.*?)_*$")
+        re3 = re.compile(r"_*complete_genome")
+        re4 = re.compile(r"(.{78}).+")
+        taxon = re0.sub("", taxon)
+        taxon = re1.sub("_", taxon)
+        taxon = re2.sub(r"\1", taxon)
+        taxon = re3.sub("", taxon)
+        taxon = re4.sub(r"\1", taxon)
     # iterating through sequence
     ambig_cnt = 0
     encoding = guess_type(file)[1]  # uses file extension
@@ -78,12 +78,12 @@ def _rename_name(x, output_dir):
     with open(out_file, mode="w") as outFH:
         with _open(file) as f:
             for i, record in enumerate(SeqIO.parse(f, "fasta")):
-                name = record.name
-                name = re0.sub("", name)
-                name = re1.sub("_", name)
-                name = re2.sub(r"\1", name)
-                name = re3.sub("", name)
-                name = re4.sub(r"\1", name)
+                # name = record.name
+                # name = re0.sub("", name)
+                # name = re1.sub("_", name)
+                # name = re2.sub(r"\1", name)
+                # name = re3.sub("", name)
+                # name = re4.sub(r"\1", name)
                 name = f"{taxon}__seq-{i}"
                 # name = name.lstrip('>') + '__seq{}'.format(i)
                 record.id = name
@@ -108,7 +108,7 @@ def rename_genomes(genome_table, cpus, output_dir):
                 total=len(genomes),
                 leave=False,
                 ncols=100,
-                desc=f"Genomes processed",
+                desc="Genomes processed",
             )
         )
         p.close()
@@ -439,7 +439,6 @@ def generate_fragments(
     seq_depth = exp_data["n_reads"]
     files_modern = {}
     files_ancient = {}
-
     # Case when onlyAncient is False
     # Here we will need to run for modern and ancient
     if x["onlyAncient"] is False:
@@ -460,14 +459,22 @@ def generate_fragments(
                 debug=debug,
             )
             # Run deamSim
-            mis_file = get_misincorporation_file(
-                misincorporation_file=deamSim_params["-mapdamage"],
-                out_file=frag_data["deamSim_mis_ofile"],
-                accession=x["accession"],
-            )
+
+            parms = process_params_deamSim(deamSim_params)
+            if "-mapdamage" in parms.keys():
+                mis_file = get_misincorporation_file(
+                    misincorporation_file=deamSim_params["-mapdamage"],
+                    out_file=frag_data["deamSim_mis_ofile"],
+                    accession=x["accession"],
+                )
+                parms = deamSim_params.copy()
+                parms["-mapdamage"] = mis_file
+            else:
+                parms = deamSim_params.copy()
+
             run_deamSim(
                 exe=deamSim_exe,
-                params=deamSim_params,
+                params=parms,
                 ofile=frag_data["deamSim_ofile"],
                 fasta=frag_data["fragSim_ofile"],
                 libprep=libprep,
@@ -728,27 +735,38 @@ def _combine_reads(read_files, output_dir, output_file, fastx, remove_adapters):
             if fastx == "fastq":
                 if "SR" not in os.path.split(in_file)[1]:
                     p0 = re.compile(
-                        "(\S+)---(\S+)----(\S+)___art-(ancient|modern).\d.fq"
+                        r"(\S+)---(\S+)----(\S+)___art-(ancient|modern).\d.fq"
                     )
+                    p0a = re.compile(r"(\S+)---(\S+)___art-(ancient|modern).\d.fq")
                     p1 = re.compile(
-                        "(\S+):([+\-]):(\d+):(\d+):(\d+)(?:_DEAM:(.*))?\-\d\/(\d)$"
+                        r"(\S+):([+\-]):(\d+):(\d+):(\d+)(?:_DEAM:(.*))?\-\d\/(\d)$"
                     )
                 else:
                     p0 = re.compile(
-                        "(\S+)---(\S+)----(\S+)___art-(ancient|modern).SR.fq"
+                        r"(\S+)---(\S+)----(\S+)___art-(ancient|modern).SR.fq"
                     )
+                    p0a = re.compile(r"(\S+)---(\S+)___art-(ancient|modern).SR.fq")
                     p1 = re.compile(
-                        "(\S+):([+\-]):(\d+):(\d+):(\d+)(?:_DEAM:(.*))?\-\d$"
+                        r"(\S+):([+\-]):(\d+):(\d+):(\d+)(?:_DEAM:(.*))?\-\d$"
                     )
             elif fastx == "fasta":
-                p0 = re.compile("(\S+)---(\S+)----(\S+)___\S+-(\S+).fasta\S+")
-                p1 = re.compile("(\S+):([+\-]):(\d+):(\d+):(\d+)(?:_DEAM:(.*))?")
+                p0 = re.compile(
+                    r"(\S+)---(\S+)----(\S+)___\S+-(ancient|modern).fasta\S+"
+                )
+                p0a = re.compile(r"(\S+)---(\S+)___\S+-(ancient|modern).fasta\S+")
+                p1 = re.compile(r"(\S+):([+\-]):(\d+):(\d+):(\d+)(?:_DEAM:(.*))?")
 
             m0 = re.match(p0, os.path.split(in_file)[1])
-            comm = m0.group(1)
-            taxon = f"{m0.group(2)}----{m0.group(3)}"
+            if m0 is None:
+                m0 = re.match(p0a, os.path.split(in_file)[1])
+                comm = m0.group(1)
+                taxon = f"{m0.group(2)}"
+                frag_type = m0.group(3)
+            else:
+                comm = m0.group(1)
+                taxon = f"{m0.group(2)}----{m0.group(3)}"
+                frag_type = m0.group(4)
 
-            frag_type = m0.group(4)
             encoding = guess_type(in_file)[1]  # uses file extension
             _open = partial(gzip.open, mode="rt") if encoding == "gzip" else open
             with _open(in_file) as f:
@@ -1034,7 +1052,7 @@ def get_ancient_reads(args):
                 total=len(ancient_genomes_data),
                 leave=False,
                 ncols=100,
-                desc=f"Genomes processed",
+                desc="Genomes processed",
             )
         )
         p.close()
@@ -1070,7 +1088,7 @@ def get_ancient_reads(args):
                 total=len(comm_files),
                 leave=False,
                 ncols=100,
-                desc=f"Files processed",
+                desc="Files processed",
             )
         )
         p.close()
@@ -1086,7 +1104,7 @@ def get_ancient_reads(args):
     for comm in df["comm"].unique():
         comm = str(comm)
         read_files[comm] = {}
-        for index, val in df_files.iteritems():
+        for index, val in df_files.items():
             if comm == str(index[0]):
                 read_files[comm][index[1]] = val
 
