@@ -11,6 +11,8 @@ from functools import partial
 from pathlib import Path
 from pandarallel import pandarallel
 
+log = logging.getLogger("my_logger")
+
 
 def get_codon_table():
     codons_table = Bio.Data.CodonTable.standard_dna_table.forward_table
@@ -20,25 +22,45 @@ def get_codon_table():
     return codons_table
 
 
-def get_headers(records, pattern):
+def get_headers(records):
     """
     Get information of the reads encoded in the headers
     """
+    pattern = re.compile(r"(\S+)___(\S+)---(\d+):(\S+):([+\-]):(\d+):(\d+):(\d+):(.*)")
+    pattern0 = re.compile(
+        r"(\S+)___(\S+)____(\S+)---(\d+):(\S+):([+\-]):(\d+):(\d+):(\d+):(.*)"
+    )
     for i, record in records:
+        m0 = re.match(pattern0, record.id)
         m1 = re.match(pattern, record.id)
-        reads = {
-            "Chromosome": m1.group(2),
-            "Start": int(m1.group(6)),
-            "End": m1.group(7),
-            "Name": m1.group(0),
-            "Strand": m1.group(5),
-            "Start_read": int(m1.group(6)),
-            "End_read": int(m1.group(7)),
-            "Strand_read": m1.group(5),
-            "type": m1.group(4),
-            "read_length": m1.group(8),
-            "damage": m1.group(9),
-        }
+        if m0:
+            reads = {
+                "Chromosome": f"{m0.group(2)}----{m0.group(3)}",
+                "Start": int(m0.group(7)),
+                "End": m0.group(8),
+                "Name": m0.group(0),
+                "Strand": m0.group(6),
+                "Start_read": int(m0.group(7)),
+                "End_read": int(m0.group(8)),
+                "Strand_read": m0.group(6),
+                "type": m0.group(5),
+                "read_length": m0.group(9),
+                "damage": m0.group(10),
+            }
+        else:
+            reads = {
+                "Chromosome": m1.group(2),
+                "Start": int(m1.group(6)),
+                "End": m1.group(7),
+                "Name": m1.group(0),
+                "Strand": m1.group(5),
+                "Start_read": int(m1.group(6)),
+                "End_read": int(m1.group(7)),
+                "Strand_read": m1.group(5),
+                "type": m1.group(4),
+                "read_length": m1.group(8),
+                "damage": m1.group(9),
+            }
         yield reads
 
 
@@ -47,7 +69,7 @@ def get_prodigal_coords(x):
     Get prodigal coordinates from headers
     """
     # get coords from prodigal fasta header
-    s = re.split("\#|\s", x.replace(" ", ""))
+    s = re.split(r"\#|\s", x.replace(" ", ""))
     coords = [int(i) for i in s[1:4]]
     return pd.Series(coords)
 
@@ -56,9 +78,15 @@ def fasta_to_dataframe(
     infile, header_sep=None, key="name", seqkey="sequence", feature="CDS"
 ):
     """Get fasta proteins into dataframe"""
-    recs = SeqIO.parse(infile, "fasta")
+    encoding = guess_type(infile)[1]  # uses file extension
+    _open = partial(gzip.open, mode="rt") if encoding == "gzip" else open
+    # recs = SeqIO.parse(infile, "fasta")
     keys = [key, seqkey, "description"]
-    data = [(r.name, str(r.seq), str(r.description)) for r in recs]
+    data = []
+    with _open(infile) as handle:
+        for r in SeqIO.parse(handle, "fasta"):
+            data.append((r.name, str(r.seq), str(r.description)))
+
     df = pd.DataFrame(data, columns=(keys))
     df["type"] = feature
     # fix bad names
@@ -82,8 +110,10 @@ def get_gene_coordinates(fna):
     # df_genes = df_genes.rename(columns={"sequence_x": "nt_seq", "sequence_y": "aa_seq"})
     df_nt["Strand"] = df_nt["Strand"].astype(str).str.replace("-1", "-")
     df_nt["Strand"] = df_nt["Strand"].astype(str).str.replace("1", "+")
-    df_nt["Chromosome"] = df_nt["name"].str.extract(r"(\S+)_\d+")
-    df_nt.drop(["description", "sequence"], 1)
+    df_nt["Chromosome"] = df_nt["name"].str.extract(r"(.*)_\d+")
+    df_nt["Chromosome"] = df_nt["Chromosome"].astype(str).str.replace("___", "---")
+    df_nt["Chromosome"] = df_nt["Chromosome"].astype(str).str.replace("---_", "----")
+    df_nt.drop(columns=["description", "sequence"])
     df_nt = df_nt[["name", "type", "Chromosome", "Start", "End", "Strand"]]
     df_nt = df_nt.rename(columns={"name": "gene_name"})
     df_nt = pr.PyRanges(df_nt)
@@ -109,7 +139,7 @@ def get_intersections(reads, genes, genome, min_len=0):
     # j = df_reads.overlap(df_genes, invert=True)
     gr.intersect_length = gr.lengths()
     # print(j.df[j.df['intersect_length'].astype(int) != j.df['length'].astype(int)])
-    gr = pr.PyRanges(gr.df.drop(["Strand"], 1))
+    gr = pr.PyRanges(gr.df.drop(columns=["Strand"]))
     # TODO Optimize retrieval of fasta sequences
     gr.intersect_seq = pr.get_fasta(gr, genome[0])
     gr.intersect_seq = gr.df.parallel_apply(revcomp, var="intersect_seq", axis=1)
@@ -382,8 +412,8 @@ def get_seqs_inframe(x):
 log = logging.getLogger("my_logger")
 
 
-def analyze_proteins(x, files, gene_predictions, min_len, outdir, debug, nproc):
-    pandarallel.initialize(nb_workers=nproc, progress_bar=False, verbose=False)
+def analyze_proteins(x, files, gene_predictions, min_len, outdir, debug, threads=1):
+    pandarallel.initialize(nb_workers=threads, progress_bar=False, verbose=False)
 
     comm = x[0]
     genome = x[1]
@@ -401,12 +431,9 @@ def analyze_proteins(x, files, gene_predictions, min_len, outdir, debug, nproc):
         encoding = guess_type(deam_file)[1]  # uses file extension
         _open = partial(gzip.open, mode="rt") if encoding == "gzip" else open
 
-        pattern = re.compile(
-            "(\S+)___(\S+)---(\d+):(\S+):([+\-]):(\d+):(\d+):(\d+):(.*)"
-        )
         with _open(deam_file) as f:
             records = enumerate(SeqIO.parse(f, "fasta"))
-            recs = get_headers(records=records, pattern=pattern)
+            recs = get_headers(records=records)
             df = pd.DataFrame(recs)
         if debug:
             log.info("Reading reads...")
@@ -433,7 +460,7 @@ def analyze_proteins(x, files, gene_predictions, min_len, outdir, debug, nproc):
                 "Strand": "Strand_gene",
             }
             r2g_intersections = r2g_intersections.join(
-                genes.drop("type"), report_overlap=True
+                genes.drop("type"), report_overlap=True, apply_strand_suffix=False
             )
             r2g_intersections = pr.PyRanges(
                 r2g_intersections.df[
@@ -485,6 +512,7 @@ def analyze_proteins(x, files, gene_predictions, min_len, outdir, debug, nproc):
                 "community",
                 "read_name",
                 "gene_name",
+                "index",
                 "chromosome",
                 "damage",
                 "damage_intersection",
@@ -492,14 +520,31 @@ def analyze_proteins(x, files, gene_predictions, min_len, outdir, debug, nproc):
                 "damage_inframe_ag",
                 "damage_aaseq_diffs",
                 "damage_codon_diffs",
+                "Overlap",
+                "intersect_length",
                 "intersect_seq",
                 "intersect_seq_inframe_aa",
                 "intersect_seq_inframe_nt",
+                "Start",
+                "End",
+                "Start_read",
+                "End_read",
+                "Strand_read",
+                "read_length",
+                "Start_gene",
+                "End_gene",
+                "Strand_gene",
                 "damaged_seq",
                 "damaged_seq_inframe_aa",
                 "damaged_seq_inframe_nt",
+                "damaged_seq_length",
+                "nondamaged_seq",
+                "sequence",
+                "sequence_aa",
+                "type",
             ]
-            aa_damage.to_csv(
+
+            aa_damage[columns].to_csv(
                 path_or_buf=outfile,
                 sep="\t",
                 header=True,
